Preferences

Struct Preferences 

pub struct Preferences { /* private fields */ }
Re-exports the corresponding SystemConfiguration wrappers. Wraps SCPreferencesRef.

Implementations

Source

impl Preferences

pub fn type_id() -> u64

Wraps SCPreferencesGetTypeID.

pub fn new(name: &str, prefs_id: Option<&str>) -> Result<Self>

Wraps SCPreferencesCreate.

pub fn new_with_authorization( name: &str, prefs_id: Option<&str>, ) -> Result<Self>

Wraps SCPreferencesCreateWithAuthorization.

pub unsafe fn new_with_authorization_raw( name: &str, prefs_id: Option<&str>, authorization: Option<NonNull<c_void>>, ) -> Result<Self>

Safety

authorization must be a valid AuthorizationRef obtained from a compatible Security-framework binding, and it must remain valid for the lifetime requirements imposed by SCPreferences.

pub fn new_with_callback<F>( name: &str, prefs_id: Option<&str>, callback: F, ) -> Result<Self>
where F: FnMut(PreferencesNotification) + Send + 'static,

Wraps SCPreferencesCreate with SCPreferencesSetCallback.

pub fn new_with_authorization_and_callback<F>( name: &str, prefs_id: Option<&str>, callback: F, ) -> Result<Self>
where F: FnMut(PreferencesNotification) + Send + 'static,

Wraps SCPreferencesCreateWithAuthorization with SCPreferencesSetCallback.

pub unsafe fn new_with_authorization_raw_and_callback<F>( name: &str, prefs_id: Option<&str>, authorization: Option<NonNull<c_void>>, callback: F, ) -> Result<Self>
where F: FnMut(PreferencesNotification) + Send + 'static,

Safety

authorization must be a valid AuthorizationRef obtained from a compatible Security-framework binding, and it must remain valid for the lifetime requirements imposed by SCPreferences.

pub fn set_callback<F>(&mut self, callback: F) -> Result<()>
where F: FnMut(PreferencesNotification) + Send + 'static,

Wraps a helper on SCPreferencesRef.

pub fn clear_callback(&mut self) -> Result<()>

Wraps a helper on SCPreferencesRef.

pub fn schedule_with_run_loop_current(&self) -> Result<()>

Wraps SCPreferencesScheduleWithRunLoopCurrent.

pub fn unschedule_from_run_loop_current(&self) -> Result<()>

Wraps SCPreferencesUnscheduleFromRunLoopCurrent.

pub fn set_dispatch_queue_global(&self) -> Result<()>

Wraps SCPreferencesSetDispatchQueueGlobal.

pub fn clear_dispatch_queue(&self) -> Result<()>

Wraps SCPreferencesClearDispatchQueue.

pub fn lock(&self, wait: bool) -> Result<()>

Wraps SCPreferencesLock.

pub fn commit_changes(&self) -> Result<()>

Wraps SCPreferencesCommitChanges.

pub fn apply_changes(&self) -> Result<()>

Wraps SCPreferencesApplyChanges.

pub fn unlock(&self) -> Result<()>

Wraps SCPreferencesUnlock.

pub fn synchronize(&self)

Wraps SCPreferencesSynchronize.

pub fn signature(&self) -> Option<String>

Wraps SCPreferencesCopySignature.

pub fn copy_key_list(&self) -> Vec<String>

Wraps SCPreferencesCopyKeyList.

pub fn get_value(&self, key: &str) -> Result<Option<PropertyList>>

Wraps SCPreferencesGetValue.

pub fn add_value(&self, key: &str, value: &PropertyList) -> Result<()>

Wraps SCPreferencesAddValue.

pub fn set_value(&self, key: &str, value: &PropertyList) -> Result<()>

Wraps SCPreferencesSetValue.

pub fn remove_value(&self, key: &str) -> Result<()>

Wraps SCPreferencesRemoveValue.

pub fn path_create_unique_child(&self, prefix: &str) -> Result<Option<String>>

Wraps SCPreferencesPathCreateUniqueChild.

pub fn path_get_value(&self, path: &str) -> Result<Option<PropertyList>>

Wraps SCPreferencesPathGetValue.

Wraps SCPreferencesPathGetLink.

pub fn path_set_value(&self, path: &str, value: &PropertyList) -> Result<()>

Wraps SCPreferencesPathSetValue.

Wraps SCPreferencesPathSetLink.

pub fn path_remove_value(&self, path: &str) -> Result<()>

Wraps SCPreferencesPathRemoveValue.

pub fn set_computer_name(&self, name: Option<&str>) -> Result<()>

Wraps SCPreferencesSetComputerName.

pub fn set_local_host_name(&self, name: Option<&str>) -> Result<()>

Wraps SCPreferencesSetLocalHostName.

pub fn network_services(&self) -> Vec<NetworkService>

Wraps a helper on SCPreferencesRef.