Preferences

Struct Preferences 

pub struct Preferences { /* private fields */ }

Implementations

Source

impl Preferences

pub fn type_id() -> u64

pub fn new(name: &str, prefs_id: Option<&str>) -> Result<Self>

Examples found in repository?
examples/07_network_sets.rs (line 4)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let prefs = Preferences::new("systemconfiguration-rs.network-sets-example", None)?;
5    let current = NetworkSet::copy_current(&prefs).and_then(|set| set.name());
6    println!("current_set={current:?}");
7    for set in NetworkSet::copy_all(&prefs) {
8        println!("set_id={:?} name={:?} services={}", set.set_id(), set.name(), set.copy_services().len());
9    }
10    Ok(())
11}
More examples
Hide additional examples
examples/06_network_services.rs (line 4)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let prefs = Preferences::new("systemconfiguration-rs.network-services-example", None)?;
5    for service in prefs.network_services() {
6        println!(
7            "id={:?} enabled={} name={:?} protocols={}",
8            service.service_id()?,
9            service.is_enabled(),
10            service.name()?,
11            service.copy_protocols().len()
12        );
13    }
14    Ok(())
15}
examples/04_preferences_session.rs (line 4)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let prefs = Preferences::new("systemconfiguration-rs.preferences-example", None)?;
5    let keys = prefs.copy_key_list();
6    println!("key_count={}", keys.len());
7    if let Some(first_key) = keys.first() {
8        println!("first_key={first_key}");
9        println!("first_value_present={}", prefs.get_value(first_key)?.is_some());
10    }
11    println!("signature_present={}", prefs.signature().is_some());
12    Ok(())
13}
examples/09_network_protocol.rs (line 4)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let prefs = Preferences::new("systemconfiguration-rs.network-protocol-example", None)?;
5    if let Some(protocol) = NetworkService::copy_all(&prefs)
6        .into_iter()
7        .flat_map(|service| service.copy_protocols())
8        .next()
9    {
10        println!(
11            "protocol_type={:?} enabled={} has_config={}",
12            protocol.protocol_type(),
13            protocol.is_enabled(),
14            protocol.configuration().is_some()
15        );
16    } else {
17        println!("no network protocols available");
18    }
19    Ok(())
20}
pub fn new_with_authorization( name: &str, prefs_id: Option<&str>, ) -> Result<Self>

pub unsafe fn new_with_authorization_raw( name: &str, prefs_id: Option<&str>, authorization: Option<NonNull<c_void>>, ) -> Result<Self>

Safety

authorization must be a valid AuthorizationRef obtained from a compatible Security-framework binding, and it must remain valid for the lifetime requirements imposed by SCPreferences.

pub fn new_with_callback<F>( name: &str, prefs_id: Option<&str>, callback: F, ) -> Result<Self>
where F: FnMut(PreferencesNotification) + Send + 'static,

pub fn new_with_authorization_and_callback<F>( name: &str, prefs_id: Option<&str>, callback: F, ) -> Result<Self>
where F: FnMut(PreferencesNotification) + Send + 'static,

pub unsafe fn new_with_authorization_raw_and_callback<F>( name: &str, prefs_id: Option<&str>, authorization: Option<NonNull<c_void>>, callback: F, ) -> Result<Self>
where F: FnMut(PreferencesNotification) + Send + 'static,

Safety

authorization must be a valid AuthorizationRef obtained from a compatible Security-framework binding, and it must remain valid for the lifetime requirements imposed by SCPreferences.

pub fn set_callback<F>(&mut self, callback: F) -> Result<()>
where F: FnMut(PreferencesNotification) + Send + 'static,

pub fn clear_callback(&mut self) -> Result<()>

pub fn schedule_with_run_loop_current(&self) -> Result<()>

pub fn unschedule_from_run_loop_current(&self) -> Result<()>

pub fn set_dispatch_queue_global(&self) -> Result<()>

pub fn clear_dispatch_queue(&self) -> Result<()>

pub fn lock(&self, wait: bool) -> Result<()>

pub fn commit_changes(&self) -> Result<()>

pub fn apply_changes(&self) -> Result<()>

pub fn unlock(&self) -> Result<()>

pub fn synchronize(&self)

pub fn signature(&self) -> Option<String>

Examples found in repository?
examples/04_preferences_session.rs (line 11)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let prefs = Preferences::new("systemconfiguration-rs.preferences-example", None)?;
5    let keys = prefs.copy_key_list();
6    println!("key_count={}", keys.len());
7    if let Some(first_key) = keys.first() {
8        println!("first_key={first_key}");
9        println!("first_value_present={}", prefs.get_value(first_key)?.is_some());
10    }
11    println!("signature_present={}", prefs.signature().is_some());
12    Ok(())
13}
pub fn copy_key_list(&self) -> Vec<String>

Examples found in repository?
examples/04_preferences_session.rs (line 5)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let prefs = Preferences::new("systemconfiguration-rs.preferences-example", None)?;
5    let keys = prefs.copy_key_list();
6    println!("key_count={}", keys.len());
7    if let Some(first_key) = keys.first() {
8        println!("first_key={first_key}");
9        println!("first_value_present={}", prefs.get_value(first_key)?.is_some());
10    }
11    println!("signature_present={}", prefs.signature().is_some());
12    Ok(())
13}
pub fn get_value(&self, key: &str) -> Result<Option<PropertyList>>

Examples found in repository?
examples/04_preferences_session.rs (line 9)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let prefs = Preferences::new("systemconfiguration-rs.preferences-example", None)?;
5    let keys = prefs.copy_key_list();
6    println!("key_count={}", keys.len());
7    if let Some(first_key) = keys.first() {
8        println!("first_key={first_key}");
9        println!("first_value_present={}", prefs.get_value(first_key)?.is_some());
10    }
11    println!("signature_present={}", prefs.signature().is_some());
12    Ok(())
13}
pub fn add_value(&self, key: &str, value: &PropertyList) -> Result<()>

pub fn set_value(&self, key: &str, value: &PropertyList) -> Result<()>

pub fn remove_value(&self, key: &str) -> Result<()>

pub fn path_create_unique_child(&self, prefix: &str) -> Result<Option<String>>

pub fn path_get_value(&self, path: &str) -> Result<Option<PropertyList>>

pub fn path_set_value(&self, path: &str, value: &PropertyList) -> Result<()>

pub fn path_remove_value(&self, path: &str) -> Result<()>

pub fn set_computer_name(&self, name: Option<&str>) -> Result<()>

pub fn set_local_host_name(&self, name: Option<&str>) -> Result<()>

pub fn network_services(&self) -> Vec<NetworkService>

Examples found in repository?
examples/06_network_services.rs (line 5)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4    let prefs = Preferences::new("systemconfiguration-rs.network-services-example", None)?;
5    for service in prefs.network_services() {
6        println!(
7            "id={:?} enabled={} name={:?} protocols={}",
8            service.service_id()?,
9            service.is_enabled(),
10            service.name()?,
11            service.copy_protocols().len()
12        );
13    }
14    Ok(())
15}